@@ -55,11 +55,24 @@ def paint():
     draw()
     
 def b64tofile():
+    menu = '''
+please choose mode (1/2):
+    - 1. encode
+        Base64 encode a file
+    - 2. decode
+        Base64 decode a file
+'''
+    mode = input(menu)
     f1 = input('input file name:')
     f2 = input('Output file name:')
+    while mode not in ['1','2']:
+        mode = input('Please choose mode (1/2):')
     f = open(f1,'rb').read()
-    from base64 import b64decode
-    df = b64decode(f)
+    from base64 import b64decode,b64encode
+    if mode == '1':
+        df = b64decode(f)
+    elif mode == '2':
+        df = b64encode(f)
     with open(f2,'wb') as ff:
         ff.write(df)
     
